import { IPublicTypeTitleContent, IPublicTypeLocationChildrenDetail, IPublicModelNode, IPublicModelPluginContext } from '@alilc/lowcode-types';
import { Tree } from './tree';
/**
 * 大纲树过滤结果
 */
export interface FilterResult {
    filterWorking: boolean;
    matchChild: boolean;
    matchSelf: boolean;
    keywords: string;
}
export default class TreeNode {
    readonly pluginContext: IPublicModelPluginContext;
    onFilterResultChanged: () => void;
    onExpandedChanged: (expanded: boolean) => void;
    onHiddenChanged: (hidden: boolean) => void;
    onLockedChanged: (locked: boolean) => void;
    onTitleLabelChanged: (treeNode: TreeNode) => void;
    onExpandableChanged: (expandable: boolean) => void;
    get id(): string;
    /**
     * 是否可以展开
     */
    get expandable(): boolean;
    /**
     * 触发 onExpandableChanged 回调
     */
    notifyExpandableChanged(): void;
    /**
     * 插入"线"位置信息
     */
    get dropDetail(): IPublicTypeLocationChildrenDetail | undefined | null;
    get depth(): number;
    isRoot(includeOriginalRoot?: boolean): boolean;
    /**
     * 是否是响应投放区
     */
    isResponseDropping(): boolean;
    isFocusingNode(): boolean;
    /**
     * 默认为折叠状态
     * 在初始化根节点时，设置为展开状态
     */
    private _expanded;
    get expanded(): boolean;
    setExpanded(value: boolean): void;
    get detecting(): boolean;
    get hidden(): boolean;
    setHidden(flag: boolean): void;
    get locked(): boolean;
    setLocked(flag: boolean): void;
    get selected(): boolean;
    get title(): IPublicTypeTitleContent;
    get titleLabel(): any;
    setTitleLabel(label: string): void;
    get icon(): import("@alilc/lowcode-types").IPublicTypeIconType;
    get parent(): TreeNode | null;
    get slots(): TreeNode[];
    get children(): TreeNode[] | null;
    /**
     * 是否是容器，允许子节点拖入
     */
    isContainer(): boolean;
    /**
     * 判断是否有"插槽"
     */
    hasSlots(): boolean;
    hasChildren(): boolean;
    select(isMulti: boolean): void;
    /**
     * 展开节点，支持依次展开父节点
     */
    expand(tryExpandParents?: boolean): void;
    expandParents(): void;
    private _node;
    get node(): IPublicModelNode;
    readonly tree: Tree;
    constructor(tree: Tree, node: IPublicModelNode, pluginContext: IPublicModelPluginContext);
    setNode(node: IPublicModelNode): void;
    private _filterResult;
    get filterReult(): FilterResult;
    setFilterReult(val: FilterResult): void;
}
